/**
 * NetworkLoadBalancer API
 * This describes the network load balancer API.
 * OpenAPI spec version: 20200501
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2022, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as responses from "./response";
import { NetworkLoadBalancerWaiter } from "./networkloadbalancer-waiter";
export declare enum NetworkLoadBalancerApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class NetworkLoadBalancerClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": NetworkLoadBalancerWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: null;
    protected _httpOptions: any;
    targetService: string;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new NetworkLoadBalancerWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): NetworkLoadBalancerWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): NetworkLoadBalancerWaiter;
    /**
     * Moves a network load balancer into a different compartment within the same tenancy. For information about moving resources
     * between compartments, see [Moving Resources to a Different Compartment](https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeNetworkLoadBalancerCompartmentRequest
     * @return ChangeNetworkLoadBalancerCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.40.0/networkloadbalancer/ChangeNetworkLoadBalancerCompartment.ts.html |here} to see how to use ChangeNetworkLoadBalancerCompartment API.
     */
    changeNetworkLoadBalancerCompartment(changeNetworkLoadBalancerCompartmentRequest: requests.ChangeNetworkLoadBalancerCompartmentRequest): Promise<responses.ChangeNetworkLoadBalancerCompartmentResponse>;
    /**
     * Adds a backend server to a backend set.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateBackendRequest
     * @return CreateBackendResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.40.0/networkloadbalancer/CreateBackend.ts.html |here} to see how to use CreateBackend API.
     */
    createBackend(createBackendRequest: requests.CreateBackendRequest): Promise<responses.CreateBackendResponse>;
    /**
     * Adds a backend set to a network load balancer.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateBackendSetRequest
     * @return CreateBackendSetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.40.0/networkloadbalancer/CreateBackendSet.ts.html |here} to see how to use CreateBackendSet API.
     */
    createBackendSet(createBackendSetRequest: requests.CreateBackendSetRequest): Promise<responses.CreateBackendSetResponse>;
    /**
     * Adds a listener to a network load balancer.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateListenerRequest
     * @return CreateListenerResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.40.0/networkloadbalancer/CreateListener.ts.html |here} to see how to use CreateListener API.
     */
    createListener(createListenerRequest: requests.CreateListenerRequest): Promise<responses.CreateListenerResponse>;
    /**
     * Creates a network load balancer.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateNetworkLoadBalancerRequest
     * @return CreateNetworkLoadBalancerResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.40.0/networkloadbalancer/CreateNetworkLoadBalancer.ts.html |here} to see how to use CreateNetworkLoadBalancer API.
     */
    createNetworkLoadBalancer(createNetworkLoadBalancerRequest: requests.CreateNetworkLoadBalancerRequest): Promise<responses.CreateNetworkLoadBalancerResponse>;
    /**
     * Removes a backend server from a given network load balancer and backend set.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteBackendRequest
     * @return DeleteBackendResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.40.0/networkloadbalancer/DeleteBackend.ts.html |here} to see how to use DeleteBackend API.
     */
    deleteBackend(deleteBackendRequest: requests.DeleteBackendRequest): Promise<responses.DeleteBackendResponse>;
    /**
       * Deletes the specified backend set. Note that deleting a backend set removes its backend servers from the network load balancer.
  * <p>
  Before you can delete a backend set, you must remove it from any active listeners.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param DeleteBackendSetRequest
       * @return DeleteBackendSetResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.40.0/networkloadbalancer/DeleteBackendSet.ts.html |here} to see how to use DeleteBackendSet API.
       */
    deleteBackendSet(deleteBackendSetRequest: requests.DeleteBackendSetRequest): Promise<responses.DeleteBackendSetResponse>;
    /**
     * Deletes a listener from a network load balancer.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteListenerRequest
     * @return DeleteListenerResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.40.0/networkloadbalancer/DeleteListener.ts.html |here} to see how to use DeleteListener API.
     */
    deleteListener(deleteListenerRequest: requests.DeleteListenerRequest): Promise<responses.DeleteListenerResponse>;
    /**
     * Deletes a network load balancer resource by identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteNetworkLoadBalancerRequest
     * @return DeleteNetworkLoadBalancerResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.40.0/networkloadbalancer/DeleteNetworkLoadBalancer.ts.html |here} to see how to use DeleteNetworkLoadBalancer API.
     */
    deleteNetworkLoadBalancer(deleteNetworkLoadBalancerRequest: requests.DeleteNetworkLoadBalancerRequest): Promise<responses.DeleteNetworkLoadBalancerResponse>;
    /**
     * Retrieves the configuration information for the specified backend server.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetBackendRequest
     * @return GetBackendResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.40.0/networkloadbalancer/GetBackend.ts.html |here} to see how to use GetBackend API.
     */
    getBackend(getBackendRequest: requests.GetBackendRequest): Promise<responses.GetBackendResponse>;
    /**
     * Retrieves the current health status of the specified backend server.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetBackendHealthRequest
     * @return GetBackendHealthResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.40.0/networkloadbalancer/GetBackendHealth.ts.html |here} to see how to use GetBackendHealth API.
     */
    getBackendHealth(getBackendHealthRequest: requests.GetBackendHealthRequest): Promise<responses.GetBackendHealthResponse>;
    /**
     * Retrieves the configuration information for the specified backend set.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetBackendSetRequest
     * @return GetBackendSetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.40.0/networkloadbalancer/GetBackendSet.ts.html |here} to see how to use GetBackendSet API.
     */
    getBackendSet(getBackendSetRequest: requests.GetBackendSetRequest): Promise<responses.GetBackendSetResponse>;
    /**
     * Retrieves the health status for the specified backend set.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetBackendSetHealthRequest
     * @return GetBackendSetHealthResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.40.0/networkloadbalancer/GetBackendSetHealth.ts.html |here} to see how to use GetBackendSetHealth API.
     */
    getBackendSetHealth(getBackendSetHealthRequest: requests.GetBackendSetHealthRequest): Promise<responses.GetBackendSetHealthResponse>;
    /**
     * Retrieves the health check policy information for a given network load balancer and backend set.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetHealthCheckerRequest
     * @return GetHealthCheckerResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.40.0/networkloadbalancer/GetHealthChecker.ts.html |here} to see how to use GetHealthChecker API.
     */
    getHealthChecker(getHealthCheckerRequest: requests.GetHealthCheckerRequest): Promise<responses.GetHealthCheckerResponse>;
    /**
     * Retrieves listener properties associated with a given network load balancer and listener name.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetListenerRequest
     * @return GetListenerResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.40.0/networkloadbalancer/GetListener.ts.html |here} to see how to use GetListener API.
     */
    getListener(getListenerRequest: requests.GetListenerRequest): Promise<responses.GetListenerResponse>;
    /**
     * Retrieves network load balancer configuration information by identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetNetworkLoadBalancerRequest
     * @return GetNetworkLoadBalancerResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.40.0/networkloadbalancer/GetNetworkLoadBalancer.ts.html |here} to see how to use GetNetworkLoadBalancer API.
     */
    getNetworkLoadBalancer(getNetworkLoadBalancerRequest: requests.GetNetworkLoadBalancerRequest): Promise<responses.GetNetworkLoadBalancerResponse>;
    /**
     * Retrieves the health status for the specified network load balancer.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetNetworkLoadBalancerHealthRequest
     * @return GetNetworkLoadBalancerHealthResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.40.0/networkloadbalancer/GetNetworkLoadBalancerHealth.ts.html |here} to see how to use GetNetworkLoadBalancerHealth API.
     */
    getNetworkLoadBalancerHealth(getNetworkLoadBalancerHealthRequest: requests.GetNetworkLoadBalancerHealthRequest): Promise<responses.GetNetworkLoadBalancerHealthResponse>;
    /**
     * Retrieves the details of the work request with the given identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetWorkRequestRequest
     * @return GetWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.40.0/networkloadbalancer/GetWorkRequest.ts.html |here} to see how to use GetWorkRequest API.
     */
    getWorkRequest(getWorkRequestRequest: requests.GetWorkRequestRequest): Promise<responses.GetWorkRequestResponse>;
    /**
     * Lists all backend sets associated with a given network load balancer.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListBackendSetsRequest
     * @return ListBackendSetsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.40.0/networkloadbalancer/ListBackendSets.ts.html |here} to see how to use ListBackendSets API.
     */
    listBackendSets(listBackendSetsRequest: requests.ListBackendSetsRequest): Promise<responses.ListBackendSetsResponse>;
    /**
     * Lists the backend servers for a given network load balancer and backend set.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListBackendsRequest
     * @return ListBackendsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.40.0/networkloadbalancer/ListBackends.ts.html |here} to see how to use ListBackends API.
     */
    listBackends(listBackendsRequest: requests.ListBackendsRequest): Promise<responses.ListBackendsResponse>;
    /**
     * Lists all listeners associated with a given network load balancer.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListListenersRequest
     * @return ListListenersResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.40.0/networkloadbalancer/ListListeners.ts.html |here} to see how to use ListListeners API.
     */
    listListeners(listListenersRequest: requests.ListListenersRequest): Promise<responses.ListListenersResponse>;
    /**
     * Lists the summary health statuses for all network load balancers in the specified compartment.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListNetworkLoadBalancerHealthsRequest
     * @return ListNetworkLoadBalancerHealthsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.40.0/networkloadbalancer/ListNetworkLoadBalancerHealths.ts.html |here} to see how to use ListNetworkLoadBalancerHealths API.
     */
    listNetworkLoadBalancerHealths(listNetworkLoadBalancerHealthsRequest: requests.ListNetworkLoadBalancerHealthsRequest): Promise<responses.ListNetworkLoadBalancerHealthsResponse>;
    /**
     * Returns a list of network load balancers.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListNetworkLoadBalancersRequest
     * @return ListNetworkLoadBalancersResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.40.0/networkloadbalancer/ListNetworkLoadBalancers.ts.html |here} to see how to use ListNetworkLoadBalancers API.
     */
    listNetworkLoadBalancers(listNetworkLoadBalancersRequest: requests.ListNetworkLoadBalancersRequest): Promise<responses.ListNetworkLoadBalancersResponse>;
    /**
     * Lists the available network load balancer policies.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListNetworkLoadBalancersPoliciesRequest
     * @return ListNetworkLoadBalancersPoliciesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.40.0/networkloadbalancer/ListNetworkLoadBalancersPolicies.ts.html |here} to see how to use ListNetworkLoadBalancersPolicies API.
     */
    listNetworkLoadBalancersPolicies(listNetworkLoadBalancersPoliciesRequest: requests.ListNetworkLoadBalancersPoliciesRequest): Promise<responses.ListNetworkLoadBalancersPoliciesResponse>;
    /**
     * This API has been deprecated so it won't return the updated list of supported protocls.
     * Lists all supported traffic protocols.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListNetworkLoadBalancersProtocolsRequest
     * @return ListNetworkLoadBalancersProtocolsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.40.0/networkloadbalancer/ListNetworkLoadBalancersProtocols.ts.html |here} to see how to use ListNetworkLoadBalancersProtocols API.
     */
    listNetworkLoadBalancersProtocols(listNetworkLoadBalancersProtocolsRequest: requests.ListNetworkLoadBalancersProtocolsRequest): Promise<responses.ListNetworkLoadBalancersProtocolsResponse>;
    /**
     * Return a (paginated) list of errors for a given work request.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListWorkRequestErrorsRequest
     * @return ListWorkRequestErrorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.40.0/networkloadbalancer/ListWorkRequestErrors.ts.html |here} to see how to use ListWorkRequestErrors API.
     */
    listWorkRequestErrors(listWorkRequestErrorsRequest: requests.ListWorkRequestErrorsRequest): Promise<responses.ListWorkRequestErrorsResponse>;
    /**
     * Returns a (paginated) list of logs for a given work request.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListWorkRequestLogsRequest
     * @return ListWorkRequestLogsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.40.0/networkloadbalancer/ListWorkRequestLogs.ts.html |here} to see how to use ListWorkRequestLogs API.
     */
    listWorkRequestLogs(listWorkRequestLogsRequest: requests.ListWorkRequestLogsRequest): Promise<responses.ListWorkRequestLogsResponse>;
    /**
     * Lists all work requests.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListWorkRequestsRequest
     * @return ListWorkRequestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.40.0/networkloadbalancer/ListWorkRequests.ts.html |here} to see how to use ListWorkRequests API.
     */
    listWorkRequests(listWorkRequestsRequest: requests.ListWorkRequestsRequest): Promise<responses.ListWorkRequestsResponse>;
    /**
     * Updates the configuration of a backend server within the specified backend set.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateBackendRequest
     * @return UpdateBackendResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.40.0/networkloadbalancer/UpdateBackend.ts.html |here} to see how to use UpdateBackend API.
     */
    updateBackend(updateBackendRequest: requests.UpdateBackendRequest): Promise<responses.UpdateBackendResponse>;
    /**
     * Updates a backend set.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateBackendSetRequest
     * @return UpdateBackendSetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.40.0/networkloadbalancer/UpdateBackendSet.ts.html |here} to see how to use UpdateBackendSet API.
     */
    updateBackendSet(updateBackendSetRequest: requests.UpdateBackendSetRequest): Promise<responses.UpdateBackendSetResponse>;
    /**
     * Updates the health check policy for a given network load balancer and backend set.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateHealthCheckerRequest
     * @return UpdateHealthCheckerResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.40.0/networkloadbalancer/UpdateHealthChecker.ts.html |here} to see how to use UpdateHealthChecker API.
     */
    updateHealthChecker(updateHealthCheckerRequest: requests.UpdateHealthCheckerRequest): Promise<responses.UpdateHealthCheckerResponse>;
    /**
     * Updates a listener for a given network load balancer.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateListenerRequest
     * @return UpdateListenerResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.40.0/networkloadbalancer/UpdateListener.ts.html |here} to see how to use UpdateListener API.
     */
    updateListener(updateListenerRequest: requests.UpdateListenerRequest): Promise<responses.UpdateListenerResponse>;
    /**
     * Updates the network load balancer
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateNetworkLoadBalancerRequest
     * @return UpdateNetworkLoadBalancerResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.40.0/networkloadbalancer/UpdateNetworkLoadBalancer.ts.html |here} to see how to use UpdateNetworkLoadBalancer API.
     */
    updateNetworkLoadBalancer(updateNetworkLoadBalancerRequest: requests.UpdateNetworkLoadBalancerRequest): Promise<responses.UpdateNetworkLoadBalancerResponse>;
    /**
     * Updates the network security groups associated with the specified network load balancer.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateNetworkSecurityGroupsRequest
     * @return UpdateNetworkSecurityGroupsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.40.0/networkloadbalancer/UpdateNetworkSecurityGroups.ts.html |here} to see how to use UpdateNetworkSecurityGroups API.
     */
    updateNetworkSecurityGroups(updateNetworkSecurityGroupsRequest: requests.UpdateNetworkSecurityGroupsRequest): Promise<responses.UpdateNetworkSecurityGroupsResponse>;
}
